@@ -1,4 +1,4 @@
-# Data from Magurran 1988, p. 162
+## Data from Magurran 1988, p. 162
 trees <- IncidenceMatrix(
   data = c(1, 1, 1, 0, 0, 0,
            1, 1, 1, 1, 1, 1,
@@ -11,16 +11,15 @@ trees <- IncidenceMatrix(
                   c("Birch", "Oak", "Rowan", "Beech", "Hazel", "Holly"))
 )
 
-# Whittaker's measure
+## Whittaker's measure
 turnover(trees, "whittaker") # 1
 
-# Cody's measure
+## Cody's measure
 turnover(trees, "cody") # 3
 
-# Routledge's measures
+## Routledge's measures
 turnover(trees, method = c("routledge1", "routledge2", "routledge3"),
-         simplify = TRUE)
-# 0.29 0.56 1.75
+         simplify = TRUE) ## 0.29 0.56 1.75
 
-# Wilson and Shmida's measure
+## Wilson and Shmida's measure
 turnover(trees, "wilson") # 1
